/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.bestimmungstau.indikator;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import de.bsvrz.ibv.anastau.bestimmungstau.parameter.ISobParameterObserver;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.Strasse;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.VerkehrModellNetz;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Verwaltung der Störfallindikatoren für eine Instanz der Stauobjektbestimmung,
 * d.h. für ein VerkehrsmodellNetz.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class StoerfallIndikatorVerwaltung implements IStoerfallIndikatoren {

	/**
	 * Logger für Debugausgaben.
	 */
	private static final Debug LOGGER = Debug.getLogger();

	/**
	 * Menge der verwalteten Straßenobjekte.
	 */
	private final Map<Strasse, ISobStrasse> strassen = new HashMap<>();

	/**
	 * Konstruktor.<br>
	 * Die Funktion erstellt ein Modul für die Verwaltung von Stauobjekten für
	 * das übergebene VerkehrsmodellNetz.
	 *
	 * @param parameter
	 *            die Verwaltung der Parameter für die Stauobjektbestimmung
	 * @param netz
	 *            das Netz
	 */
	public StoerfallIndikatorVerwaltung(final ISobParameterObserver parameter, final VerkehrModellNetz netz) {

		for (final Strasse strasse : netz.getStrassen()) {
			StoerfallIndikatorVerwaltung.LOGGER.finer("Initialisiere Straße: " + strasse.getName());
			strassen.put(strasse, new SobStrasse(netz, strasse, parameter));
		}
		StoerfallIndikatorVerwaltung.LOGGER
				.config("Störfallindikatorverwaltung für Netz: " + netz.getName() + " initialisiert");
	}

	@Override
	public final Collection<ISobStrasse> getStrassen() {
		return strassen.values();
	}

	@Override
	public final void sichereSituation() {
		for (final ISobStrasse strasse : strassen.values()) {
			for (final IFahrtRichtung richtung : strasse.getFahrtRichtungen()) {
				for (final ISobIndikator indikator : richtung.getElemente()) {
					indikator.sichereSituation();
				}
			}
		}
	}
}
