/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.bestimmungstau.parameter;

import java.util.Collection;

import de.bsvrz.dav.daf.main.config.Aspect;

/**
 * Schnittstelle für ein Modul zur Verwaltung der Parameter der
 * Stauobjektbestimmung.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public interface ISobParameterObserver {
	/**
	 * fügt dem Modul einen Listener hinzu, der benachrichtigt werden soll, wenn
	 * sich die Paraameter ändern.
	 *
	 * @param listener
	 *            der Listener
	 */
	void addParameterListener(ISobParameterListener listener);

	/**
	 * liefert die virtuelle Anfangslänge eines Stauobjekts ohne eigene
	 * Ausdehnung.
	 *
	 * @return die Anfangsl&auml;nge
	 */
	float getAnfangsLaenge();

	/**
	 * liefert den maximalen Störfallindikatorabstand.
	 *
	 * @return der Abstand
	 */
	float getMaxSiAbstand();

	/**
	 * liefert die Güte, die erforderlich ist, um einen Indikator zu verwenden.
	 *
	 * @return die G&uuml;te
	 */
	float getMinSiGuete();

	/**
	 * gibt die Parameter als Zeichenkette aus.
	 *
	 * @return die Parameter als Zeichenkette
	 */
	String getParameterString();

	/**
	 * liefert den Parameter a1 für die Berechnung der maximalen Verlängerung
	 * eines Staus durch die Prognose.
	 *
	 * @return der Parameter
	 */
	float getPrognoseA1();

	/**
	 * liefert den Parameter a2 für die Berechnung der maximalen Verlängerung
	 * eines Staus durch die Prognose.
	 *
	 * @return der Parameter
	 */
	float getPrognoseA2();

	/**
	 * liefert den Parameter a3 für die Berechnung der maximalen Verlängerung
	 * eines Staus durch die Prognose.
	 *
	 * @return der Parameter
	 */
	float getPrognoseA3();

	/**
	 * liefert die Stromabseitige Verlängerung.
	 *
	 * @return die Verlängerung
	 */
	float getStromabVerlaengerung();

	/**
	 * liefert die Länge eines ungestörten Bereichs innerhalb eines Stauobjekts,
	 * der zu dessen sofortiger Teilung führt.
	 *
	 * @return die Länge
	 */
	float getTeilungLaenge();

	/**
	 * liefert die Verzögerungszeit der Teilung eines Stauobjekts, wenn die
	 * Teilungslänge nicht erreicht wurde in Millisekunden.
	 *
	 * @return die Verzögerung
	 */
	long getTeilungsVerzoegerung();

	/**
	 * liefert die Liste der Aspekte der verwendeten Verfahren für die
	 * Ermittlung des Störfallzustand an den eingesetzten Störfallindikatoren.
	 *
	 * @return die Aspekte der Verfahren
	 */
	Collection<Aspect> getVerfahren();

	/**
	 * liefert die Zykluszeit für die Stauobjektbestimmung.
	 *
	 * @return die Zeit
	 */
	long getZyklusZeit();

	/**
	 * entfernt einen Listener, der über geänderte Parameter informiert wurde.
	 *
	 * @param listener
	 *            der Listener
	 */
	void removeParameterListener(ISobParameterListener listener);
}
