/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.spez;

import de.bsvrz.sys.funclib.bitctrl.modell.AnmeldeException;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnitt;

/**
 * Repräsentation des MQ2 des Testnetzes (siehe Prüfspezifikation).
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class TestMQ2 extends TestMQ {

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Boolean[] ANFRAGETYPEN = { null, true, null, null, null, null, true };

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Double[][] GLDATEN = { {}, { 4200.0, 3540.0, 3210.0 }, { 5040.0, 5460.0, 5670.0 },
			{ 5040.0, 5040.0, 5040.0 }, { 5100.0, 5130.0, 5145.0 }, { 5220.0, 5280.0, 5310.0 },
			{ 4860.0, 4680.0, 4590.0 }, { 4860.0, 4860.0, 4860.0 }, { 5700.0, 6120.0, 6330.0 },
			{ 4380.0, 3720.0, 3390.0 }, { 5220.0, 5640.0, 5850.0 }, { 4800.0, 4590.0, 4485.0 },
			{ 3900.0, 3450.0, 3225.0 }, { 2500.0, 1800.0, 1450.0 }, { 1800.0, 1450.0, 1275.0 },
			{ 1500.0, 1350.0, 1275.0 } };

	/**
	 * Konstruktor.
	 *
	 * @param mq
	 *            der verwendete Messquerschnitt
	 * @param start
	 *            der Startzeitpunkt des Tests
	 * @param intervall
	 *            das Intervall für die Phasen des Tests
	 * @throws AnmeldeException
	 *             eine erforderliche Anmeldung beim Datenverteiler ist
	 *             fehlgeschlagen
	 */
	public TestMQ2(final MessQuerschnitt mq, final long start, final long intervall) throws AnmeldeException {
		super(mq, start, intervall);
		// TODO Auto-generated constructor stub
	}

	@Override
	public Boolean[] getGlAnfrageTypen() {
		return TestMQ2.ANFRAGETYPEN;
	}

	@Override
	public Double[] getPhasenDaten(final int phasenNummer, final boolean nurLangFristig) {
		if (TestMQ2.GLDATEN.length > phasenNummer) {
			return TestMQ2.GLDATEN[phasenNummer];
		}
		return new Double[] {};
	}
}
