/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.spez;

import de.bsvrz.ibv.anastau.spez.SpezifikationIT.TestVariante;
import de.bsvrz.sys.funclib.bitctrl.modell.AnmeldeException;
import de.bsvrz.sys.funclib.bitctrl.modell.DatensendeException;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnitt;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.parameter.PdFundamentalDiagramm;

/**
 * Repräsentation des MQ3 des Testnetzes (siehe Prüfspezifikation).
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class TestMQ3 extends TestMQ {

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Boolean[] ANFRAGETYPEN = { null, null, null, null, null, null, null, null, null, false, true,
			false };

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Double[][] GLDATEN = { {}, { 4560.0, 4380.0, 4290.0 }, { 4200.0, 4020.0, 3930.0 },
			{ 4980.0, 5370.0, 5565.0 }, { 4080.0, 3630.0, 3405.0 }, { 5220.0, 5790.0, 6075.0 },
			{ 3720.0, 2970.0, 2595.0 }, { 4020.0, 4170.0, 4245.0 }, { 4680.0, 5010.0, 5175.0 },
			{ 4100.0, 3810.0, 3665.0 }, { 4320.0, 4430.0, 4485.0 }, { 2900.0, 2190.0, 1835.0 },
			{ 3800.0, 4275.0, 4512.5 }, { 3500.0, 3350.0, 3275.0 }, { 3000.0, 2750.0, 2625.0 },
			{ 2100.0, 1650.0, 1425.0 }

	};

	/**
	 * Konstruktor.
	 *
	 * @param mq
	 *            der verwendete Messquerschnitt
	 * @param start
	 *            der Startzeitpunkt des Tests
	 * @param intervall
	 *            das Intervall für die Phasen des Tests
	 * @throws AnmeldeException
	 *             eine erforderliche Anmeldung beim Datenverteiler ist
	 *             fehlgeschlagen
	 * @throws DatensendeException
	 *             Parameterdaten für Fundamentaldiagramm konnten nicht
	 *             versendet werden
	 */
	public TestMQ3(final MessQuerschnitt mq, final long start, final long intervall)
			throws AnmeldeException, DatensendeException {
		super(mq, start, intervall);

		final PdFundamentalDiagramm datenSatz = mq.getParameterDatensatz(PdFundamentalDiagramm.class);
		datenSatz.anmeldenSender();
		final PdFundamentalDiagramm.Daten datum = datenSatz.erzeugeDatum();
		datum.setQ0(3600);
		datum.setK0((short) 0);
		datum.setV0((short) 0);
		datum.setVFrei((short) 0);
		datenSatz.sendeDaten(datum);
		datenSatz.abmeldenSender();
	}

	@Override
	public Boolean[] getGlAnfrageTypen() {
		return TestMQ3.ANFRAGETYPEN;
	}

	@Override
	protected double getGuete(final int i, final TestVariante variante) {
		double result = super.getGuete(i, variante);
		if (variante == TestVariante.C) {
			if (i == 8) {
				result = 0.1;
			}
		}
		return result;
	}

	@Override
	public Double[] getPhasenDaten(final int phasenNummer, final boolean nurLangFristig) {
		if (TestMQ3.GLDATEN.length > phasenNummer) {
			return TestMQ3.GLDATEN[phasenNummer];
		}
		return new Double[] {};
	}
}
