/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.spez;

import de.bsvrz.sys.funclib.bitctrl.modell.AnmeldeException;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnitt;

/**
 * Repräsentation des MQ der Abfahrt der AS2 (siehe Prüfspezifikation).
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class TestMQAs2Ab extends TestMQ {

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Boolean[] ANFRAGETYPEN = { null, true, null, null, null, null, true, true };

	/** die Ganglinien des MQ für die verschiedenen Phasen. */
	private static final Double[][] GLDATEN = { {}, { 32.0, 33.0, 33.5 }, { 37.0, 39.5, 40.75 }, { 35.0, 34.0, 33.5 },
			{ 33.0, 32.0, 31.5 }, { 32.0, 31.5, 31.25 }, { 20.0, 14.0, 11.0 }, { 25.0, 27.5, 28.75 },
			{ 24.0, 23.5, 23.25 }, { 23.0, 22.5, 22.25 }, { 27.0, 29.0, 30.0 }, { 28.0, 28.5, 28.75 },
			{ 30.0, 31.0, 31.5 }, { 32.0, 33.0, 33.5 }, { 34.0, 35.0, 35.5 }, { 44.0, 49.0, 51.5 } };

	/** die Ganglinie des MQ für langfristige Prognose. */
	private static final Double[] GLLANG = { 17.0, 23.0, 22.0, 21.0, 21.0, 20.0, 21.0, 24.0, 26.0, 28.0, 29.0, 31.0,
			31.0, 30.0, 30.0, 30.0, 30.0, 30.0, 30.0, 28.0 };

	/**
	 * Konstruktor.
	 *
	 * @param mq
	 *            der verwendete Messquerschnitt
	 * @param start
	 *            der Startzeitpunkt des Tests
	 * @param intervall
	 *            das Intervall für die Phasen des Tests
	 * @throws AnmeldeException
	 *             eine erforderliche Anmeldung beim Datenverteiler ist
	 *             fehlgeschlagen
	 */
	public TestMQAs2Ab(final MessQuerschnitt mq, final long start, final long intervall) throws AnmeldeException {
		super(mq, start, intervall);
		// TODO Auto-generated constructor stub
	}

	@Override
	public Boolean[] getGlAnfrageTypen() {
		return TestMQAs2Ab.ANFRAGETYPEN;
	}

	@Override
	public Double[] getPhasenDaten(final int phasenNummer, final boolean nurLangFristig) {
		Double[] result = null;
		if (nurLangFristig) {
			if (TestMQAs2Ab.GLLANG.length > phasenNummer) {
				result = new Double[TestMQAs2Ab.GLLANG.length - phasenNummer];
				System.arraycopy(TestMQAs2Ab.GLLANG, phasenNummer, result, 0, TestMQAs2Ab.GLLANG.length - phasenNummer);
			}
		} else {
			if (TestMQAs2Ab.GLDATEN.length > phasenNummer) {
				result = TestMQAs2Ab.GLDATEN[phasenNummer];
			}
		}

		if (result == null) {
			result = new Double[] {};
		}
		return result;
	}
}
